PyKoopman Examples
==================

Here we provide examples of different ways PyKoopman can be used.

`Tutorial Koopman Linear System <https://github.com/dynamicslab/pykoopman/blob/master/examples/tutorial_koopman_linearsystem.ipynb>`_
------------------------------
This notebook shows how to apply PyKoopman to a spatiotemporal linear system, using the Dynamic Mode Decomposition (DMD).
